from sdog.monitor import main
from sdog.notifier import SDNotifier
